@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     ResourceOwnerType,
@@ -32,30 +32,30 @@ from .paginator import (
     ListResourcesPaginator,
 )
 from .type_defs import (
-    AcceptResourceShareInvitationResponseResponseTypeDef,
-    AssociateResourceSharePermissionResponseResponseTypeDef,
-    AssociateResourceShareResponseResponseTypeDef,
-    CreateResourceShareResponseResponseTypeDef,
-    DeleteResourceShareResponseResponseTypeDef,
-    DisassociateResourceSharePermissionResponseResponseTypeDef,
-    DisassociateResourceShareResponseResponseTypeDef,
-    EnableSharingWithAwsOrganizationResponseResponseTypeDef,
-    GetPermissionResponseResponseTypeDef,
-    GetResourcePoliciesResponseResponseTypeDef,
-    GetResourceShareAssociationsResponseResponseTypeDef,
-    GetResourceShareInvitationsResponseResponseTypeDef,
-    GetResourceSharesResponseResponseTypeDef,
-    ListPendingInvitationResourcesResponseResponseTypeDef,
-    ListPermissionsResponseResponseTypeDef,
-    ListPrincipalsResponseResponseTypeDef,
-    ListResourceSharePermissionsResponseResponseTypeDef,
-    ListResourcesResponseResponseTypeDef,
-    ListResourceTypesResponseResponseTypeDef,
-    PromoteResourceShareCreatedFromPolicyResponseResponseTypeDef,
-    RejectResourceShareInvitationResponseResponseTypeDef,
+    AcceptResourceShareInvitationResponseTypeDef,
+    AssociateResourceSharePermissionResponseTypeDef,
+    AssociateResourceShareResponseTypeDef,
+    CreateResourceShareResponseTypeDef,
+    DeleteResourceShareResponseTypeDef,
+    DisassociateResourceSharePermissionResponseTypeDef,
+    DisassociateResourceShareResponseTypeDef,
+    EnableSharingWithAwsOrganizationResponseTypeDef,
+    GetPermissionResponseTypeDef,
+    GetResourcePoliciesResponseTypeDef,
+    GetResourceShareAssociationsResponseTypeDef,
+    GetResourceShareInvitationsResponseTypeDef,
+    GetResourceSharesResponseTypeDef,
+    ListPendingInvitationResourcesResponseTypeDef,
+    ListPermissionsResponseTypeDef,
+    ListPrincipalsResponseTypeDef,
+    ListResourceSharePermissionsResponseTypeDef,
+    ListResourcesResponseTypeDef,
+    ListResourceTypesResponseTypeDef,
+    PromoteResourceShareCreatedFromPolicyResponseTypeDef,
+    RejectResourceShareInvitationResponseTypeDef,
     TagFilterTypeDef,
     TagTypeDef,
-    UpdateResourceShareResponseResponseTypeDef,
+    UpdateResourceShareResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -100,22 +100,27 @@ class Exceptions:
     UnknownResourceException: Type[BotocoreClientError]
 
 
-class RAMClient:
+class RAMClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        RAMClient exceptions.
+        """
 
     def accept_resource_share_invitation(
         self, *, resourceShareInvitationArn: str, clientToken: str = None
-    ) -> AcceptResourceShareInvitationResponseResponseTypeDef:
+    ) -> AcceptResourceShareInvitationResponseTypeDef:
         """
         Accepts an invitation to a resource share from another AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#accept_resource_share_invitation)
         """
 
@@ -126,12 +131,12 @@ class RAMClient:
         resourceArns: List[str] = None,
         principals: List[str] = None,
         clientToken: str = None
-    ) -> AssociateResourceShareResponseResponseTypeDef:
+    ) -> AssociateResourceShareResponseTypeDef:
         """
         Associates the specified resource share with the specified principals and
         resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.associate_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.associate_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate_resource_share)
         """
 
@@ -143,11 +148,11 @@ class RAMClient:
         replace: bool = None,
         clientToken: str = None,
         permissionVersion: int = None
-    ) -> AssociateResourceSharePermissionResponseResponseTypeDef:
+    ) -> AssociateResourceSharePermissionResponseTypeDef:
         """
         Associates a permission with a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate_resource_share_permission)
         """
 
@@ -155,7 +160,7 @@ class RAMClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#can_paginate)
         """
 
@@ -169,21 +174,21 @@ class RAMClient:
         allowExternalPrincipals: bool = None,
         clientToken: str = None,
         permissionArns: List[str] = None
-    ) -> CreateResourceShareResponseResponseTypeDef:
+    ) -> CreateResourceShareResponseTypeDef:
         """
         Creates a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.create_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.create_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#create_resource_share)
         """
 
     def delete_resource_share(
         self, *, resourceShareArn: str, clientToken: str = None
-    ) -> DeleteResourceShareResponseResponseTypeDef:
+    ) -> DeleteResourceShareResponseTypeDef:
         """
         Deletes the specified resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.delete_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.delete_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#delete_resource_share)
         """
 
@@ -194,32 +199,32 @@ class RAMClient:
         resourceArns: List[str] = None,
         principals: List[str] = None,
         clientToken: str = None
-    ) -> DisassociateResourceShareResponseResponseTypeDef:
+    ) -> DisassociateResourceShareResponseTypeDef:
         """
         Disassociates the specified principals or resources from the specified resource
         share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.disassociate_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.disassociate_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate_resource_share)
         """
 
     def disassociate_resource_share_permission(
         self, *, resourceShareArn: str, permissionArn: str, clientToken: str = None
-    ) -> DisassociateResourceSharePermissionResponseResponseTypeDef:
+    ) -> DisassociateResourceSharePermissionResponseTypeDef:
         """
         Disassociates an AWS RAM permission from a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate_resource_share_permission)
         """
 
     def enable_sharing_with_aws_organization(
         self,
-    ) -> EnableSharingWithAwsOrganizationResponseResponseTypeDef:
+    ) -> EnableSharingWithAwsOrganizationResponseTypeDef:
         """
         Enables resource sharing within your AWS Organization.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#enable_sharing_with_aws_organization)
         """
 
@@ -233,17 +238,17 @@ class RAMClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#generate_presigned_url)
         """
 
     def get_permission(
         self, *, permissionArn: str, permissionVersion: int = None
-    ) -> GetPermissionResponseResponseTypeDef:
+    ) -> GetPermissionResponseTypeDef:
         """
         Gets the contents of an AWS RAM permission in JSON format.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_permission)
         """
 
@@ -254,11 +259,11 @@ class RAMClient:
         principal: str = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> GetResourcePoliciesResponseResponseTypeDef:
+    ) -> GetResourcePoliciesResponseTypeDef:
         """
         Gets the policies for the specified resources that you own and have shared.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_resource_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_resource_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_policies)
         """
 
@@ -272,11 +277,11 @@ class RAMClient:
         associationStatus: ResourceShareAssociationStatusType = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> GetResourceShareAssociationsResponseResponseTypeDef:
+    ) -> GetResourceShareAssociationsResponseTypeDef:
         """
         Gets the resources or principals for the resource shares that you own.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_resource_share_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_resource_share_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_share_associations)
         """
 
@@ -287,11 +292,11 @@ class RAMClient:
         resourceShareArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> GetResourceShareInvitationsResponseResponseTypeDef:
+    ) -> GetResourceShareInvitationsResponseTypeDef:
         """
         Gets the invitations that you have received for resource shares.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_share_invitations)
         """
 
@@ -306,33 +311,33 @@ class RAMClient:
         nextToken: str = None,
         maxResults: int = None,
         permissionArn: str = None
-    ) -> GetResourceSharesResponseResponseTypeDef:
+    ) -> GetResourceSharesResponseTypeDef:
         """
         Gets the resource shares that you own or the resource shares that are shared
         with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_resource_shares)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_resource_shares)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_shares)
         """
 
     def list_pending_invitation_resources(
         self, *, resourceShareInvitationArn: str, nextToken: str = None, maxResults: int = None
-    ) -> ListPendingInvitationResourcesResponseResponseTypeDef:
+    ) -> ListPendingInvitationResourcesResponseTypeDef:
         """
         Lists the resources in a resource share that is shared with you but that the
         invitation is still pending for.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_pending_invitation_resources)
         """
 
     def list_permissions(
         self, *, resourceType: str = None, nextToken: str = None, maxResults: int = None
-    ) -> ListPermissionsResponseResponseTypeDef:
+    ) -> ListPermissionsResponseTypeDef:
         """
         Lists the AWS RAM permissions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_permissions)
         """
 
@@ -346,32 +351,32 @@ class RAMClient:
         resourceShareArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> ListPrincipalsResponseResponseTypeDef:
+    ) -> ListPrincipalsResponseTypeDef:
         """
         Lists the principals that you have shared resources with or that have shared
         resources with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_principals)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_principals)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_principals)
         """
 
     def list_resource_share_permissions(
         self, *, resourceShareArn: str, nextToken: str = None, maxResults: int = None
-    ) -> ListResourceSharePermissionsResponseResponseTypeDef:
+    ) -> ListResourceSharePermissionsResponseTypeDef:
         """
         Lists the AWS RAM permissions that are associated with a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resource_share_permissions)
         """
 
     def list_resource_types(
         self, *, nextToken: str = None, maxResults: int = None
-    ) -> ListResourceTypesResponseResponseTypeDef:
+    ) -> ListResourceTypesResponseTypeDef:
         """
         Lists the shareable resource types supported by AWS RAM.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_resource_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_resource_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resource_types)
         """
 
@@ -385,34 +390,34 @@ class RAMClient:
         resourceShareArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> ListResourcesResponseResponseTypeDef:
+    ) -> ListResourcesResponseTypeDef:
         """
         Lists the resources that you added to a resource shares or the resources that
         are shared with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resources)
         """
 
     def promote_resource_share_created_from_policy(
         self, *, resourceShareArn: str
-    ) -> PromoteResourceShareCreatedFromPolicyResponseResponseTypeDef:
+    ) -> PromoteResourceShareCreatedFromPolicyResponseTypeDef:
         """
         Resource shares that were created by attaching a policy to a resource are
         visible only to the resource share owner, and the resource share cannot be
         modified in AWS RAM.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#promote_resource_share_created_from_policy)
         """
 
     def reject_resource_share_invitation(
         self, *, resourceShareInvitationArn: str, clientToken: str = None
-    ) -> RejectResourceShareInvitationResponseResponseTypeDef:
+    ) -> RejectResourceShareInvitationResponseTypeDef:
         """
         Rejects an invitation to a resource share from another AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#reject_resource_share_invitation)
         """
 
@@ -420,7 +425,7 @@ class RAMClient:
         """
         Adds the specified tags to the specified resource share that you own.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#tag_resource)
         """
 
@@ -428,7 +433,7 @@ class RAMClient:
         """
         Removes the specified tags from the specified resource share that you own.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#untag_resource)
         """
 
@@ -439,11 +444,11 @@ class RAMClient:
         name: str = None,
         allowExternalPrincipals: bool = None,
         clientToken: str = None
-    ) -> UpdateResourceShareResponseResponseTypeDef:
+    ) -> UpdateResourceShareResponseTypeDef:
         """
         Updates the specified resource share that you own.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.update_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.update_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#update_resource_share)
         """
 
@@ -452,7 +457,7 @@ class RAMClient:
         self, operation_name: Literal["get_resource_policies"]
     ) -> GetResourcePoliciesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
         """
 
@@ -461,7 +466,7 @@ class RAMClient:
         self, operation_name: Literal["get_resource_share_associations"]
     ) -> GetResourceShareAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
         """
 
@@ -470,7 +475,7 @@ class RAMClient:
         self, operation_name: Literal["get_resource_share_invitations"]
     ) -> GetResourceShareInvitationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
         """
 
@@ -479,20 +484,20 @@ class RAMClient:
         self, operation_name: Literal["get_resource_shares"]
     ) -> GetResourceSharesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShares)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShares)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_principals"]) -> ListPrincipalsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.ListPrincipals)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.ListPrincipals)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resources"]) -> ListResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.ListResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.ListResources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
         """
