@@ -26,13 +26,13 @@ __all__ = (
     "GetResourceSharesPaginatorName",
     "ListPrincipalsPaginatorName",
     "ListResourcesPaginatorName",
-    "ResourceOwner",
-    "ResourceShareAssociationStatus",
-    "ResourceShareAssociationType",
-    "ResourceShareFeatureSet",
-    "ResourceShareInvitationStatus",
-    "ResourceShareStatus",
-    "ResourceStatus",
+    "ResourceOwnerType",
+    "ResourceShareAssociationStatusType",
+    "ResourceShareAssociationTypeType",
+    "ResourceShareFeatureSetType",
+    "ResourceShareInvitationStatusType",
+    "ResourceShareStatusType",
+    "ResourceStatusType",
 )
 
 
@@ -42,14 +42,14 @@ GetResourceShareInvitationsPaginatorName = Literal["get_resource_share_invitatio
 GetResourceSharesPaginatorName = Literal["get_resource_shares"]
 ListPrincipalsPaginatorName = Literal["list_principals"]
 ListResourcesPaginatorName = Literal["list_resources"]
-ResourceOwner = Literal["OTHER-ACCOUNTS", "SELF"]
-ResourceShareAssociationStatus = Literal[
+ResourceOwnerType = Literal["OTHER-ACCOUNTS", "SELF"]
+ResourceShareAssociationStatusType = Literal[
     "ASSOCIATED", "ASSOCIATING", "DISASSOCIATED", "DISASSOCIATING", "FAILED"
 ]
-ResourceShareAssociationType = Literal["PRINCIPAL", "RESOURCE"]
-ResourceShareFeatureSet = Literal["CREATED_FROM_POLICY", "PROMOTING_TO_STANDARD", "STANDARD"]
-ResourceShareInvitationStatus = Literal["ACCEPTED", "EXPIRED", "PENDING", "REJECTED"]
-ResourceShareStatus = Literal["ACTIVE", "DELETED", "DELETING", "FAILED", "PENDING"]
-ResourceStatus = Literal[
+ResourceShareAssociationTypeType = Literal["PRINCIPAL", "RESOURCE"]
+ResourceShareFeatureSetType = Literal["CREATED_FROM_POLICY", "PROMOTING_TO_STANDARD", "STANDARD"]
+ResourceShareInvitationStatusType = Literal["ACCEPTED", "EXPIRED", "PENDING", "REJECTED"]
+ResourceShareStatusType = Literal["ACTIVE", "DELETED", "DELETING", "FAILED", "PENDING"]
+ResourceStatusType = Literal[
     "AVAILABLE", "LIMIT_EXCEEDED", "PENDING", "UNAVAILABLE", "ZONAL_RESOURCE_INACCESSIBLE"
 ]
