@@ -39,12 +39,12 @@ from .literals import (
     ResourceShareStatusType,
 )
 from .type_defs import (
-    GetResourcePoliciesResponseResponseTypeDef,
-    GetResourceShareAssociationsResponseResponseTypeDef,
-    GetResourceShareInvitationsResponseResponseTypeDef,
-    GetResourceSharesResponseResponseTypeDef,
-    ListPrincipalsResponseResponseTypeDef,
-    ListResourcesResponseResponseTypeDef,
+    GetResourcePoliciesResponseTypeDef,
+    GetResourceShareAssociationsResponseTypeDef,
+    GetResourceShareInvitationsResponseTypeDef,
+    GetResourceSharesResponseTypeDef,
+    ListPrincipalsResponseTypeDef,
+    ListResourcesResponseTypeDef,
     PaginatorConfigTypeDef,
     TagFilterTypeDef,
 )
@@ -61,7 +61,7 @@ __all__ = (
 
 class GetResourcePoliciesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
     """
 
@@ -71,16 +71,16 @@ class GetResourcePoliciesPaginator(Boto3Paginator):
         resourceArns: List[str],
         principal: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetResourcePoliciesResponseResponseTypeDef]:
+    ) -> Iterator[GetResourcePoliciesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourcePolicies.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourcePolicies.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
         """
 
 
 class GetResourceShareAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
     """
 
@@ -93,16 +93,16 @@ class GetResourceShareAssociationsPaginator(Boto3Paginator):
         principal: str = None,
         associationStatus: ResourceShareAssociationStatusType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetResourceShareAssociationsResponseResponseTypeDef]:
+    ) -> Iterator[GetResourceShareAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
         """
 
 
 class GetResourceShareInvitationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
     """
 
@@ -112,16 +112,16 @@ class GetResourceShareInvitationsPaginator(Boto3Paginator):
         resourceShareInvitationArns: List[str] = None,
         resourceShareArns: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetResourceShareInvitationsResponseResponseTypeDef]:
+    ) -> Iterator[GetResourceShareInvitationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
         """
 
 
 class GetResourceSharesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShares)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShares)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
     """
 
@@ -135,16 +135,16 @@ class GetResourceSharesPaginator(Boto3Paginator):
         tagFilters: List["TagFilterTypeDef"] = None,
         permissionArn: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetResourceSharesResponseResponseTypeDef]:
+    ) -> Iterator[GetResourceSharesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShares.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShares.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
         """
 
 
 class ListPrincipalsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.ListPrincipals)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.ListPrincipals)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
     """
 
@@ -157,16 +157,16 @@ class ListPrincipalsPaginator(Boto3Paginator):
         resourceType: str = None,
         resourceShareArns: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPrincipalsResponseResponseTypeDef]:
+    ) -> Iterator[ListPrincipalsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.ListPrincipals.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.ListPrincipals.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
         """
 
 
 class ListResourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.ListResources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.ListResources)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
     """
 
@@ -179,8 +179,8 @@ class ListResourcesPaginator(Boto3Paginator):
         resourceArns: List[str] = None,
         resourceShareArns: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListResourcesResponseResponseTypeDef]:
+    ) -> Iterator[ListResourcesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.ListResources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.ListResources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
         """
