@@ -6,9 +6,9 @@ Type annotations for ram service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_ram.type_defs import AcceptResourceShareInvitationRequestTypeDef
+    from mypy_boto3_ram.type_defs import AcceptResourceShareInvitationRequestRequestTypeDef
 
-    data: AcceptResourceShareInvitationRequestTypeDef = {...}
+    data: AcceptResourceShareInvitationRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -32,49 +32,49 @@ else:
 
 
 __all__ = (
-    "AcceptResourceShareInvitationRequestTypeDef",
-    "AcceptResourceShareInvitationResponseResponseTypeDef",
-    "AssociateResourceSharePermissionRequestTypeDef",
-    "AssociateResourceSharePermissionResponseResponseTypeDef",
-    "AssociateResourceShareRequestTypeDef",
-    "AssociateResourceShareResponseResponseTypeDef",
-    "CreateResourceShareRequestTypeDef",
-    "CreateResourceShareResponseResponseTypeDef",
-    "DeleteResourceShareRequestTypeDef",
-    "DeleteResourceShareResponseResponseTypeDef",
-    "DisassociateResourceSharePermissionRequestTypeDef",
-    "DisassociateResourceSharePermissionResponseResponseTypeDef",
-    "DisassociateResourceShareRequestTypeDef",
-    "DisassociateResourceShareResponseResponseTypeDef",
-    "EnableSharingWithAwsOrganizationResponseResponseTypeDef",
-    "GetPermissionRequestTypeDef",
-    "GetPermissionResponseResponseTypeDef",
-    "GetResourcePoliciesRequestTypeDef",
-    "GetResourcePoliciesResponseResponseTypeDef",
-    "GetResourceShareAssociationsRequestTypeDef",
-    "GetResourceShareAssociationsResponseResponseTypeDef",
-    "GetResourceShareInvitationsRequestTypeDef",
-    "GetResourceShareInvitationsResponseResponseTypeDef",
-    "GetResourceSharesRequestTypeDef",
-    "GetResourceSharesResponseResponseTypeDef",
-    "ListPendingInvitationResourcesRequestTypeDef",
-    "ListPendingInvitationResourcesResponseResponseTypeDef",
-    "ListPermissionsRequestTypeDef",
-    "ListPermissionsResponseResponseTypeDef",
-    "ListPrincipalsRequestTypeDef",
-    "ListPrincipalsResponseResponseTypeDef",
-    "ListResourceSharePermissionsRequestTypeDef",
-    "ListResourceSharePermissionsResponseResponseTypeDef",
-    "ListResourceTypesRequestTypeDef",
-    "ListResourceTypesResponseResponseTypeDef",
-    "ListResourcesRequestTypeDef",
-    "ListResourcesResponseResponseTypeDef",
+    "AcceptResourceShareInvitationRequestRequestTypeDef",
+    "AcceptResourceShareInvitationResponseTypeDef",
+    "AssociateResourceSharePermissionRequestRequestTypeDef",
+    "AssociateResourceSharePermissionResponseTypeDef",
+    "AssociateResourceShareRequestRequestTypeDef",
+    "AssociateResourceShareResponseTypeDef",
+    "CreateResourceShareRequestRequestTypeDef",
+    "CreateResourceShareResponseTypeDef",
+    "DeleteResourceShareRequestRequestTypeDef",
+    "DeleteResourceShareResponseTypeDef",
+    "DisassociateResourceSharePermissionRequestRequestTypeDef",
+    "DisassociateResourceSharePermissionResponseTypeDef",
+    "DisassociateResourceShareRequestRequestTypeDef",
+    "DisassociateResourceShareResponseTypeDef",
+    "EnableSharingWithAwsOrganizationResponseTypeDef",
+    "GetPermissionRequestRequestTypeDef",
+    "GetPermissionResponseTypeDef",
+    "GetResourcePoliciesRequestRequestTypeDef",
+    "GetResourcePoliciesResponseTypeDef",
+    "GetResourceShareAssociationsRequestRequestTypeDef",
+    "GetResourceShareAssociationsResponseTypeDef",
+    "GetResourceShareInvitationsRequestRequestTypeDef",
+    "GetResourceShareInvitationsResponseTypeDef",
+    "GetResourceSharesRequestRequestTypeDef",
+    "GetResourceSharesResponseTypeDef",
+    "ListPendingInvitationResourcesRequestRequestTypeDef",
+    "ListPendingInvitationResourcesResponseTypeDef",
+    "ListPermissionsRequestRequestTypeDef",
+    "ListPermissionsResponseTypeDef",
+    "ListPrincipalsRequestRequestTypeDef",
+    "ListPrincipalsResponseTypeDef",
+    "ListResourceSharePermissionsRequestRequestTypeDef",
+    "ListResourceSharePermissionsResponseTypeDef",
+    "ListResourceTypesRequestRequestTypeDef",
+    "ListResourceTypesResponseTypeDef",
+    "ListResourcesRequestRequestTypeDef",
+    "ListResourcesResponseTypeDef",
     "PaginatorConfigTypeDef",
     "PrincipalTypeDef",
-    "PromoteResourceShareCreatedFromPolicyRequestTypeDef",
-    "PromoteResourceShareCreatedFromPolicyResponseResponseTypeDef",
-    "RejectResourceShareInvitationRequestTypeDef",
-    "RejectResourceShareInvitationResponseResponseTypeDef",
+    "PromoteResourceShareCreatedFromPolicyRequestRequestTypeDef",
+    "PromoteResourceShareCreatedFromPolicyResponseTypeDef",
+    "RejectResourceShareInvitationRequestRequestTypeDef",
+    "RejectResourceShareInvitationResponseTypeDef",
     "ResourceShareAssociationTypeDef",
     "ResourceShareInvitationTypeDef",
     "ResourceSharePermissionDetailTypeDef",
@@ -84,21 +84,21 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "ServiceNameAndResourceTypeTypeDef",
     "TagFilterTypeDef",
-    "TagResourceRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateResourceShareRequestTypeDef",
-    "UpdateResourceShareResponseResponseTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateResourceShareRequestRequestTypeDef",
+    "UpdateResourceShareResponseTypeDef",
 )
 
-_RequiredAcceptResourceShareInvitationRequestTypeDef = TypedDict(
-    "_RequiredAcceptResourceShareInvitationRequestTypeDef",
+_RequiredAcceptResourceShareInvitationRequestRequestTypeDef = TypedDict(
+    "_RequiredAcceptResourceShareInvitationRequestRequestTypeDef",
     {
         "resourceShareInvitationArn": str,
     },
 )
-_OptionalAcceptResourceShareInvitationRequestTypeDef = TypedDict(
-    "_OptionalAcceptResourceShareInvitationRequestTypeDef",
+_OptionalAcceptResourceShareInvitationRequestRequestTypeDef = TypedDict(
+    "_OptionalAcceptResourceShareInvitationRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -106,15 +106,15 @@ _OptionalAcceptResourceShareInvitationRequestTypeDef = TypedDict(
 )
 
 
-class AcceptResourceShareInvitationRequestTypeDef(
-    _RequiredAcceptResourceShareInvitationRequestTypeDef,
-    _OptionalAcceptResourceShareInvitationRequestTypeDef,
+class AcceptResourceShareInvitationRequestRequestTypeDef(
+    _RequiredAcceptResourceShareInvitationRequestRequestTypeDef,
+    _OptionalAcceptResourceShareInvitationRequestRequestTypeDef,
 ):
     pass
 
 
-AcceptResourceShareInvitationResponseResponseTypeDef = TypedDict(
-    "AcceptResourceShareInvitationResponseResponseTypeDef",
+AcceptResourceShareInvitationResponseTypeDef = TypedDict(
+    "AcceptResourceShareInvitationResponseTypeDef",
     {
         "resourceShareInvitation": "ResourceShareInvitationTypeDef",
         "clientToken": str,
@@ -122,15 +122,15 @@ AcceptResourceShareInvitationResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredAssociateResourceSharePermissionRequestTypeDef = TypedDict(
-    "_RequiredAssociateResourceSharePermissionRequestTypeDef",
+_RequiredAssociateResourceSharePermissionRequestRequestTypeDef = TypedDict(
+    "_RequiredAssociateResourceSharePermissionRequestRequestTypeDef",
     {
         "resourceShareArn": str,
         "permissionArn": str,
     },
 )
-_OptionalAssociateResourceSharePermissionRequestTypeDef = TypedDict(
-    "_OptionalAssociateResourceSharePermissionRequestTypeDef",
+_OptionalAssociateResourceSharePermissionRequestRequestTypeDef = TypedDict(
+    "_OptionalAssociateResourceSharePermissionRequestRequestTypeDef",
     {
         "replace": bool,
         "clientToken": str,
@@ -140,15 +140,15 @@ _OptionalAssociateResourceSharePermissionRequestTypeDef = TypedDict(
 )
 
 
-class AssociateResourceSharePermissionRequestTypeDef(
-    _RequiredAssociateResourceSharePermissionRequestTypeDef,
-    _OptionalAssociateResourceSharePermissionRequestTypeDef,
+class AssociateResourceSharePermissionRequestRequestTypeDef(
+    _RequiredAssociateResourceSharePermissionRequestRequestTypeDef,
+    _OptionalAssociateResourceSharePermissionRequestRequestTypeDef,
 ):
     pass
 
 
-AssociateResourceSharePermissionResponseResponseTypeDef = TypedDict(
-    "AssociateResourceSharePermissionResponseResponseTypeDef",
+AssociateResourceSharePermissionResponseTypeDef = TypedDict(
+    "AssociateResourceSharePermissionResponseTypeDef",
     {
         "returnValue": bool,
         "clientToken": str,
@@ -156,14 +156,14 @@ AssociateResourceSharePermissionResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredAssociateResourceShareRequestTypeDef = TypedDict(
-    "_RequiredAssociateResourceShareRequestTypeDef",
+_RequiredAssociateResourceShareRequestRequestTypeDef = TypedDict(
+    "_RequiredAssociateResourceShareRequestRequestTypeDef",
     {
         "resourceShareArn": str,
     },
 )
-_OptionalAssociateResourceShareRequestTypeDef = TypedDict(
-    "_OptionalAssociateResourceShareRequestTypeDef",
+_OptionalAssociateResourceShareRequestRequestTypeDef = TypedDict(
+    "_OptionalAssociateResourceShareRequestRequestTypeDef",
     {
         "resourceArns": List[str],
         "principals": List[str],
@@ -173,14 +173,15 @@ _OptionalAssociateResourceShareRequestTypeDef = TypedDict(
 )
 
 
-class AssociateResourceShareRequestTypeDef(
-    _RequiredAssociateResourceShareRequestTypeDef, _OptionalAssociateResourceShareRequestTypeDef
+class AssociateResourceShareRequestRequestTypeDef(
+    _RequiredAssociateResourceShareRequestRequestTypeDef,
+    _OptionalAssociateResourceShareRequestRequestTypeDef,
 ):
     pass
 
 
-AssociateResourceShareResponseResponseTypeDef = TypedDict(
-    "AssociateResourceShareResponseResponseTypeDef",
+AssociateResourceShareResponseTypeDef = TypedDict(
+    "AssociateResourceShareResponseTypeDef",
     {
         "resourceShareAssociations": List["ResourceShareAssociationTypeDef"],
         "clientToken": str,
@@ -188,14 +189,14 @@ AssociateResourceShareResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateResourceShareRequestTypeDef = TypedDict(
-    "_RequiredCreateResourceShareRequestTypeDef",
+_RequiredCreateResourceShareRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateResourceShareRequestRequestTypeDef",
     {
         "name": str,
     },
 )
-_OptionalCreateResourceShareRequestTypeDef = TypedDict(
-    "_OptionalCreateResourceShareRequestTypeDef",
+_OptionalCreateResourceShareRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateResourceShareRequestRequestTypeDef",
     {
         "resourceArns": List[str],
         "principals": List[str],
@@ -208,14 +209,15 @@ _OptionalCreateResourceShareRequestTypeDef = TypedDict(
 )
 
 
-class CreateResourceShareRequestTypeDef(
-    _RequiredCreateResourceShareRequestTypeDef, _OptionalCreateResourceShareRequestTypeDef
+class CreateResourceShareRequestRequestTypeDef(
+    _RequiredCreateResourceShareRequestRequestTypeDef,
+    _OptionalCreateResourceShareRequestRequestTypeDef,
 ):
     pass
 
 
-CreateResourceShareResponseResponseTypeDef = TypedDict(
-    "CreateResourceShareResponseResponseTypeDef",
+CreateResourceShareResponseTypeDef = TypedDict(
+    "CreateResourceShareResponseTypeDef",
     {
         "resourceShare": "ResourceShareTypeDef",
         "clientToken": str,
@@ -223,14 +225,14 @@ CreateResourceShareResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteResourceShareRequestTypeDef = TypedDict(
-    "_RequiredDeleteResourceShareRequestTypeDef",
+_RequiredDeleteResourceShareRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteResourceShareRequestRequestTypeDef",
     {
         "resourceShareArn": str,
     },
 )
-_OptionalDeleteResourceShareRequestTypeDef = TypedDict(
-    "_OptionalDeleteResourceShareRequestTypeDef",
+_OptionalDeleteResourceShareRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteResourceShareRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -238,14 +240,15 @@ _OptionalDeleteResourceShareRequestTypeDef = TypedDict(
 )
 
 
-class DeleteResourceShareRequestTypeDef(
-    _RequiredDeleteResourceShareRequestTypeDef, _OptionalDeleteResourceShareRequestTypeDef
+class DeleteResourceShareRequestRequestTypeDef(
+    _RequiredDeleteResourceShareRequestRequestTypeDef,
+    _OptionalDeleteResourceShareRequestRequestTypeDef,
 ):
     pass
 
 
-DeleteResourceShareResponseResponseTypeDef = TypedDict(
-    "DeleteResourceShareResponseResponseTypeDef",
+DeleteResourceShareResponseTypeDef = TypedDict(
+    "DeleteResourceShareResponseTypeDef",
     {
         "returnValue": bool,
         "clientToken": str,
@@ -253,15 +256,15 @@ DeleteResourceShareResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDisassociateResourceSharePermissionRequestTypeDef = TypedDict(
-    "_RequiredDisassociateResourceSharePermissionRequestTypeDef",
+_RequiredDisassociateResourceSharePermissionRequestRequestTypeDef = TypedDict(
+    "_RequiredDisassociateResourceSharePermissionRequestRequestTypeDef",
     {
         "resourceShareArn": str,
         "permissionArn": str,
     },
 )
-_OptionalDisassociateResourceSharePermissionRequestTypeDef = TypedDict(
-    "_OptionalDisassociateResourceSharePermissionRequestTypeDef",
+_OptionalDisassociateResourceSharePermissionRequestRequestTypeDef = TypedDict(
+    "_OptionalDisassociateResourceSharePermissionRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -269,15 +272,15 @@ _OptionalDisassociateResourceSharePermissionRequestTypeDef = TypedDict(
 )
 
 
-class DisassociateResourceSharePermissionRequestTypeDef(
-    _RequiredDisassociateResourceSharePermissionRequestTypeDef,
-    _OptionalDisassociateResourceSharePermissionRequestTypeDef,
+class DisassociateResourceSharePermissionRequestRequestTypeDef(
+    _RequiredDisassociateResourceSharePermissionRequestRequestTypeDef,
+    _OptionalDisassociateResourceSharePermissionRequestRequestTypeDef,
 ):
     pass
 
 
-DisassociateResourceSharePermissionResponseResponseTypeDef = TypedDict(
-    "DisassociateResourceSharePermissionResponseResponseTypeDef",
+DisassociateResourceSharePermissionResponseTypeDef = TypedDict(
+    "DisassociateResourceSharePermissionResponseTypeDef",
     {
         "returnValue": bool,
         "clientToken": str,
@@ -285,14 +288,14 @@ DisassociateResourceSharePermissionResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDisassociateResourceShareRequestTypeDef = TypedDict(
-    "_RequiredDisassociateResourceShareRequestTypeDef",
+_RequiredDisassociateResourceShareRequestRequestTypeDef = TypedDict(
+    "_RequiredDisassociateResourceShareRequestRequestTypeDef",
     {
         "resourceShareArn": str,
     },
 )
-_OptionalDisassociateResourceShareRequestTypeDef = TypedDict(
-    "_OptionalDisassociateResourceShareRequestTypeDef",
+_OptionalDisassociateResourceShareRequestRequestTypeDef = TypedDict(
+    "_OptionalDisassociateResourceShareRequestRequestTypeDef",
     {
         "resourceArns": List[str],
         "principals": List[str],
@@ -302,15 +305,15 @@ _OptionalDisassociateResourceShareRequestTypeDef = TypedDict(
 )
 
 
-class DisassociateResourceShareRequestTypeDef(
-    _RequiredDisassociateResourceShareRequestTypeDef,
-    _OptionalDisassociateResourceShareRequestTypeDef,
+class DisassociateResourceShareRequestRequestTypeDef(
+    _RequiredDisassociateResourceShareRequestRequestTypeDef,
+    _OptionalDisassociateResourceShareRequestRequestTypeDef,
 ):
     pass
 
 
-DisassociateResourceShareResponseResponseTypeDef = TypedDict(
-    "DisassociateResourceShareResponseResponseTypeDef",
+DisassociateResourceShareResponseTypeDef = TypedDict(
+    "DisassociateResourceShareResponseTypeDef",
     {
         "resourceShareAssociations": List["ResourceShareAssociationTypeDef"],
         "clientToken": str,
@@ -318,22 +321,22 @@ DisassociateResourceShareResponseResponseTypeDef = TypedDict(
     },
 )
 
-EnableSharingWithAwsOrganizationResponseResponseTypeDef = TypedDict(
-    "EnableSharingWithAwsOrganizationResponseResponseTypeDef",
+EnableSharingWithAwsOrganizationResponseTypeDef = TypedDict(
+    "EnableSharingWithAwsOrganizationResponseTypeDef",
     {
         "returnValue": bool,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredGetPermissionRequestTypeDef = TypedDict(
-    "_RequiredGetPermissionRequestTypeDef",
+_RequiredGetPermissionRequestRequestTypeDef = TypedDict(
+    "_RequiredGetPermissionRequestRequestTypeDef",
     {
         "permissionArn": str,
     },
 )
-_OptionalGetPermissionRequestTypeDef = TypedDict(
-    "_OptionalGetPermissionRequestTypeDef",
+_OptionalGetPermissionRequestRequestTypeDef = TypedDict(
+    "_OptionalGetPermissionRequestRequestTypeDef",
     {
         "permissionVersion": int,
     },
@@ -341,28 +344,28 @@ _OptionalGetPermissionRequestTypeDef = TypedDict(
 )
 
 
-class GetPermissionRequestTypeDef(
-    _RequiredGetPermissionRequestTypeDef, _OptionalGetPermissionRequestTypeDef
+class GetPermissionRequestRequestTypeDef(
+    _RequiredGetPermissionRequestRequestTypeDef, _OptionalGetPermissionRequestRequestTypeDef
 ):
     pass
 
 
-GetPermissionResponseResponseTypeDef = TypedDict(
-    "GetPermissionResponseResponseTypeDef",
+GetPermissionResponseTypeDef = TypedDict(
+    "GetPermissionResponseTypeDef",
     {
         "permission": "ResourceSharePermissionDetailTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredGetResourcePoliciesRequestTypeDef = TypedDict(
-    "_RequiredGetResourcePoliciesRequestTypeDef",
+_RequiredGetResourcePoliciesRequestRequestTypeDef = TypedDict(
+    "_RequiredGetResourcePoliciesRequestRequestTypeDef",
     {
         "resourceArns": List[str],
     },
 )
-_OptionalGetResourcePoliciesRequestTypeDef = TypedDict(
-    "_OptionalGetResourcePoliciesRequestTypeDef",
+_OptionalGetResourcePoliciesRequestRequestTypeDef = TypedDict(
+    "_OptionalGetResourcePoliciesRequestRequestTypeDef",
     {
         "principal": str,
         "nextToken": str,
@@ -372,14 +375,15 @@ _OptionalGetResourcePoliciesRequestTypeDef = TypedDict(
 )
 
 
-class GetResourcePoliciesRequestTypeDef(
-    _RequiredGetResourcePoliciesRequestTypeDef, _OptionalGetResourcePoliciesRequestTypeDef
+class GetResourcePoliciesRequestRequestTypeDef(
+    _RequiredGetResourcePoliciesRequestRequestTypeDef,
+    _OptionalGetResourcePoliciesRequestRequestTypeDef,
 ):
     pass
 
 
-GetResourcePoliciesResponseResponseTypeDef = TypedDict(
-    "GetResourcePoliciesResponseResponseTypeDef",
+GetResourcePoliciesResponseTypeDef = TypedDict(
+    "GetResourcePoliciesResponseTypeDef",
     {
         "policies": List[str],
         "nextToken": str,
@@ -387,14 +391,14 @@ GetResourcePoliciesResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetResourceShareAssociationsRequestTypeDef = TypedDict(
-    "_RequiredGetResourceShareAssociationsRequestTypeDef",
+_RequiredGetResourceShareAssociationsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetResourceShareAssociationsRequestRequestTypeDef",
     {
         "associationType": ResourceShareAssociationTypeType,
     },
 )
-_OptionalGetResourceShareAssociationsRequestTypeDef = TypedDict(
-    "_OptionalGetResourceShareAssociationsRequestTypeDef",
+_OptionalGetResourceShareAssociationsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetResourceShareAssociationsRequestRequestTypeDef",
     {
         "resourceShareArns": List[str],
         "resourceArn": str,
@@ -407,15 +411,15 @@ _OptionalGetResourceShareAssociationsRequestTypeDef = TypedDict(
 )
 
 
-class GetResourceShareAssociationsRequestTypeDef(
-    _RequiredGetResourceShareAssociationsRequestTypeDef,
-    _OptionalGetResourceShareAssociationsRequestTypeDef,
+class GetResourceShareAssociationsRequestRequestTypeDef(
+    _RequiredGetResourceShareAssociationsRequestRequestTypeDef,
+    _OptionalGetResourceShareAssociationsRequestRequestTypeDef,
 ):
     pass
 
 
-GetResourceShareAssociationsResponseResponseTypeDef = TypedDict(
-    "GetResourceShareAssociationsResponseResponseTypeDef",
+GetResourceShareAssociationsResponseTypeDef = TypedDict(
+    "GetResourceShareAssociationsResponseTypeDef",
     {
         "resourceShareAssociations": List["ResourceShareAssociationTypeDef"],
         "nextToken": str,
@@ -423,8 +427,8 @@ GetResourceShareAssociationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetResourceShareInvitationsRequestTypeDef = TypedDict(
-    "GetResourceShareInvitationsRequestTypeDef",
+GetResourceShareInvitationsRequestRequestTypeDef = TypedDict(
+    "GetResourceShareInvitationsRequestRequestTypeDef",
     {
         "resourceShareInvitationArns": List[str],
         "resourceShareArns": List[str],
@@ -434,8 +438,8 @@ GetResourceShareInvitationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetResourceShareInvitationsResponseResponseTypeDef = TypedDict(
-    "GetResourceShareInvitationsResponseResponseTypeDef",
+GetResourceShareInvitationsResponseTypeDef = TypedDict(
+    "GetResourceShareInvitationsResponseTypeDef",
     {
         "resourceShareInvitations": List["ResourceShareInvitationTypeDef"],
         "nextToken": str,
@@ -443,14 +447,14 @@ GetResourceShareInvitationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetResourceSharesRequestTypeDef = TypedDict(
-    "_RequiredGetResourceSharesRequestTypeDef",
+_RequiredGetResourceSharesRequestRequestTypeDef = TypedDict(
+    "_RequiredGetResourceSharesRequestRequestTypeDef",
     {
         "resourceOwner": ResourceOwnerType,
     },
 )
-_OptionalGetResourceSharesRequestTypeDef = TypedDict(
-    "_OptionalGetResourceSharesRequestTypeDef",
+_OptionalGetResourceSharesRequestRequestTypeDef = TypedDict(
+    "_OptionalGetResourceSharesRequestRequestTypeDef",
     {
         "resourceShareArns": List[str],
         "resourceShareStatus": ResourceShareStatusType,
@@ -464,14 +468,14 @@ _OptionalGetResourceSharesRequestTypeDef = TypedDict(
 )
 
 
-class GetResourceSharesRequestTypeDef(
-    _RequiredGetResourceSharesRequestTypeDef, _OptionalGetResourceSharesRequestTypeDef
+class GetResourceSharesRequestRequestTypeDef(
+    _RequiredGetResourceSharesRequestRequestTypeDef, _OptionalGetResourceSharesRequestRequestTypeDef
 ):
     pass
 
 
-GetResourceSharesResponseResponseTypeDef = TypedDict(
-    "GetResourceSharesResponseResponseTypeDef",
+GetResourceSharesResponseTypeDef = TypedDict(
+    "GetResourceSharesResponseTypeDef",
     {
         "resourceShares": List["ResourceShareTypeDef"],
         "nextToken": str,
@@ -479,14 +483,14 @@ GetResourceSharesResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListPendingInvitationResourcesRequestTypeDef = TypedDict(
-    "_RequiredListPendingInvitationResourcesRequestTypeDef",
+_RequiredListPendingInvitationResourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredListPendingInvitationResourcesRequestRequestTypeDef",
     {
         "resourceShareInvitationArn": str,
     },
 )
-_OptionalListPendingInvitationResourcesRequestTypeDef = TypedDict(
-    "_OptionalListPendingInvitationResourcesRequestTypeDef",
+_OptionalListPendingInvitationResourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalListPendingInvitationResourcesRequestRequestTypeDef",
     {
         "nextToken": str,
         "maxResults": int,
@@ -495,15 +499,15 @@ _OptionalListPendingInvitationResourcesRequestTypeDef = TypedDict(
 )
 
 
-class ListPendingInvitationResourcesRequestTypeDef(
-    _RequiredListPendingInvitationResourcesRequestTypeDef,
-    _OptionalListPendingInvitationResourcesRequestTypeDef,
+class ListPendingInvitationResourcesRequestRequestTypeDef(
+    _RequiredListPendingInvitationResourcesRequestRequestTypeDef,
+    _OptionalListPendingInvitationResourcesRequestRequestTypeDef,
 ):
     pass
 
 
-ListPendingInvitationResourcesResponseResponseTypeDef = TypedDict(
-    "ListPendingInvitationResourcesResponseResponseTypeDef",
+ListPendingInvitationResourcesResponseTypeDef = TypedDict(
+    "ListPendingInvitationResourcesResponseTypeDef",
     {
         "resources": List["ResourceTypeDef"],
         "nextToken": str,
@@ -511,8 +515,8 @@ ListPendingInvitationResourcesResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListPermissionsRequestTypeDef = TypedDict(
-    "ListPermissionsRequestTypeDef",
+ListPermissionsRequestRequestTypeDef = TypedDict(
+    "ListPermissionsRequestRequestTypeDef",
     {
         "resourceType": str,
         "nextToken": str,
@@ -521,8 +525,8 @@ ListPermissionsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListPermissionsResponseResponseTypeDef = TypedDict(
-    "ListPermissionsResponseResponseTypeDef",
+ListPermissionsResponseTypeDef = TypedDict(
+    "ListPermissionsResponseTypeDef",
     {
         "permissions": List["ResourceSharePermissionSummaryTypeDef"],
         "nextToken": str,
@@ -530,14 +534,14 @@ ListPermissionsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListPrincipalsRequestTypeDef = TypedDict(
-    "_RequiredListPrincipalsRequestTypeDef",
+_RequiredListPrincipalsRequestRequestTypeDef = TypedDict(
+    "_RequiredListPrincipalsRequestRequestTypeDef",
     {
         "resourceOwner": ResourceOwnerType,
     },
 )
-_OptionalListPrincipalsRequestTypeDef = TypedDict(
-    "_OptionalListPrincipalsRequestTypeDef",
+_OptionalListPrincipalsRequestRequestTypeDef = TypedDict(
+    "_OptionalListPrincipalsRequestRequestTypeDef",
     {
         "resourceArn": str,
         "principals": List[str],
@@ -550,14 +554,14 @@ _OptionalListPrincipalsRequestTypeDef = TypedDict(
 )
 
 
-class ListPrincipalsRequestTypeDef(
-    _RequiredListPrincipalsRequestTypeDef, _OptionalListPrincipalsRequestTypeDef
+class ListPrincipalsRequestRequestTypeDef(
+    _RequiredListPrincipalsRequestRequestTypeDef, _OptionalListPrincipalsRequestRequestTypeDef
 ):
     pass
 
 
-ListPrincipalsResponseResponseTypeDef = TypedDict(
-    "ListPrincipalsResponseResponseTypeDef",
+ListPrincipalsResponseTypeDef = TypedDict(
+    "ListPrincipalsResponseTypeDef",
     {
         "principals": List["PrincipalTypeDef"],
         "nextToken": str,
@@ -565,14 +569,14 @@ ListPrincipalsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListResourceSharePermissionsRequestTypeDef = TypedDict(
-    "_RequiredListResourceSharePermissionsRequestTypeDef",
+_RequiredListResourceSharePermissionsRequestRequestTypeDef = TypedDict(
+    "_RequiredListResourceSharePermissionsRequestRequestTypeDef",
     {
         "resourceShareArn": str,
     },
 )
-_OptionalListResourceSharePermissionsRequestTypeDef = TypedDict(
-    "_OptionalListResourceSharePermissionsRequestTypeDef",
+_OptionalListResourceSharePermissionsRequestRequestTypeDef = TypedDict(
+    "_OptionalListResourceSharePermissionsRequestRequestTypeDef",
     {
         "nextToken": str,
         "maxResults": int,
@@ -581,15 +585,15 @@ _OptionalListResourceSharePermissionsRequestTypeDef = TypedDict(
 )
 
 
-class ListResourceSharePermissionsRequestTypeDef(
-    _RequiredListResourceSharePermissionsRequestTypeDef,
-    _OptionalListResourceSharePermissionsRequestTypeDef,
+class ListResourceSharePermissionsRequestRequestTypeDef(
+    _RequiredListResourceSharePermissionsRequestRequestTypeDef,
+    _OptionalListResourceSharePermissionsRequestRequestTypeDef,
 ):
     pass
 
 
-ListResourceSharePermissionsResponseResponseTypeDef = TypedDict(
-    "ListResourceSharePermissionsResponseResponseTypeDef",
+ListResourceSharePermissionsResponseTypeDef = TypedDict(
+    "ListResourceSharePermissionsResponseTypeDef",
     {
         "permissions": List["ResourceSharePermissionSummaryTypeDef"],
         "nextToken": str,
@@ -597,8 +601,8 @@ ListResourceSharePermissionsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListResourceTypesRequestTypeDef = TypedDict(
-    "ListResourceTypesRequestTypeDef",
+ListResourceTypesRequestRequestTypeDef = TypedDict(
+    "ListResourceTypesRequestRequestTypeDef",
     {
         "nextToken": str,
         "maxResults": int,
@@ -606,8 +610,8 @@ ListResourceTypesRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListResourceTypesResponseResponseTypeDef = TypedDict(
-    "ListResourceTypesResponseResponseTypeDef",
+ListResourceTypesResponseTypeDef = TypedDict(
+    "ListResourceTypesResponseTypeDef",
     {
         "resourceTypes": List["ServiceNameAndResourceTypeTypeDef"],
         "nextToken": str,
@@ -615,14 +619,14 @@ ListResourceTypesResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListResourcesRequestTypeDef = TypedDict(
-    "_RequiredListResourcesRequestTypeDef",
+_RequiredListResourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredListResourcesRequestRequestTypeDef",
     {
         "resourceOwner": ResourceOwnerType,
     },
 )
-_OptionalListResourcesRequestTypeDef = TypedDict(
-    "_OptionalListResourcesRequestTypeDef",
+_OptionalListResourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalListResourcesRequestRequestTypeDef",
     {
         "principal": str,
         "resourceType": str,
@@ -635,14 +639,14 @@ _OptionalListResourcesRequestTypeDef = TypedDict(
 )
 
 
-class ListResourcesRequestTypeDef(
-    _RequiredListResourcesRequestTypeDef, _OptionalListResourcesRequestTypeDef
+class ListResourcesRequestRequestTypeDef(
+    _RequiredListResourcesRequestRequestTypeDef, _OptionalListResourcesRequestRequestTypeDef
 ):
     pass
 
 
-ListResourcesResponseResponseTypeDef = TypedDict(
-    "ListResourcesResponseResponseTypeDef",
+ListResourcesResponseTypeDef = TypedDict(
+    "ListResourcesResponseTypeDef",
     {
         "resources": List["ResourceTypeDef"],
         "nextToken": str,
@@ -672,29 +676,29 @@ PrincipalTypeDef = TypedDict(
     total=False,
 )
 
-PromoteResourceShareCreatedFromPolicyRequestTypeDef = TypedDict(
-    "PromoteResourceShareCreatedFromPolicyRequestTypeDef",
+PromoteResourceShareCreatedFromPolicyRequestRequestTypeDef = TypedDict(
+    "PromoteResourceShareCreatedFromPolicyRequestRequestTypeDef",
     {
         "resourceShareArn": str,
     },
 )
 
-PromoteResourceShareCreatedFromPolicyResponseResponseTypeDef = TypedDict(
-    "PromoteResourceShareCreatedFromPolicyResponseResponseTypeDef",
+PromoteResourceShareCreatedFromPolicyResponseTypeDef = TypedDict(
+    "PromoteResourceShareCreatedFromPolicyResponseTypeDef",
     {
         "returnValue": bool,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredRejectResourceShareInvitationRequestTypeDef = TypedDict(
-    "_RequiredRejectResourceShareInvitationRequestTypeDef",
+_RequiredRejectResourceShareInvitationRequestRequestTypeDef = TypedDict(
+    "_RequiredRejectResourceShareInvitationRequestRequestTypeDef",
     {
         "resourceShareInvitationArn": str,
     },
 )
-_OptionalRejectResourceShareInvitationRequestTypeDef = TypedDict(
-    "_OptionalRejectResourceShareInvitationRequestTypeDef",
+_OptionalRejectResourceShareInvitationRequestRequestTypeDef = TypedDict(
+    "_OptionalRejectResourceShareInvitationRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -702,15 +706,15 @@ _OptionalRejectResourceShareInvitationRequestTypeDef = TypedDict(
 )
 
 
-class RejectResourceShareInvitationRequestTypeDef(
-    _RequiredRejectResourceShareInvitationRequestTypeDef,
-    _OptionalRejectResourceShareInvitationRequestTypeDef,
+class RejectResourceShareInvitationRequestRequestTypeDef(
+    _RequiredRejectResourceShareInvitationRequestRequestTypeDef,
+    _OptionalRejectResourceShareInvitationRequestRequestTypeDef,
 ):
     pass
 
 
-RejectResourceShareInvitationResponseResponseTypeDef = TypedDict(
-    "RejectResourceShareInvitationResponseResponseTypeDef",
+RejectResourceShareInvitationResponseTypeDef = TypedDict(
+    "RejectResourceShareInvitationResponseTypeDef",
     {
         "resourceShareInvitation": "ResourceShareInvitationTypeDef",
         "clientToken": str,
@@ -843,8 +847,8 @@ TagFilterTypeDef = TypedDict(
     total=False,
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "resourceShareArn": str,
         "tags": List["TagTypeDef"],
@@ -860,22 +864,22 @@ TagTypeDef = TypedDict(
     total=False,
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "resourceShareArn": str,
         "tagKeys": List[str],
     },
 )
 
-_RequiredUpdateResourceShareRequestTypeDef = TypedDict(
-    "_RequiredUpdateResourceShareRequestTypeDef",
+_RequiredUpdateResourceShareRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateResourceShareRequestRequestTypeDef",
     {
         "resourceShareArn": str,
     },
 )
-_OptionalUpdateResourceShareRequestTypeDef = TypedDict(
-    "_OptionalUpdateResourceShareRequestTypeDef",
+_OptionalUpdateResourceShareRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateResourceShareRequestRequestTypeDef",
     {
         "name": str,
         "allowExternalPrincipals": bool,
@@ -885,14 +889,15 @@ _OptionalUpdateResourceShareRequestTypeDef = TypedDict(
 )
 
 
-class UpdateResourceShareRequestTypeDef(
-    _RequiredUpdateResourceShareRequestTypeDef, _OptionalUpdateResourceShareRequestTypeDef
+class UpdateResourceShareRequestRequestTypeDef(
+    _RequiredUpdateResourceShareRequestRequestTypeDef,
+    _OptionalUpdateResourceShareRequestRequestTypeDef,
 ):
     pass
 
 
-UpdateResourceShareResponseResponseTypeDef = TypedDict(
-    "UpdateResourceShareResponseResponseTypeDef",
+UpdateResourceShareResponseTypeDef = TypedDict(
+    "UpdateResourceShareResponseTypeDef",
     {
         "resourceShare": "ResourceShareTypeDef",
         "clientToken": str,
